import chalk from "chalk";
import commandLineUsage from "command-line-usage";
import { stringSorter, taskSorter } from "./utils.js";
export function formatTasks(tasks, defaultTask) {
    tasks = tasks
        .slice(0)
        .filter((task) => !task.options.hiddenFromTaskList)
        .sort(taskSorter);
    const sections = [];
    sections.push({
        header: "Available tasks",
        content: tasks.map((task) => {
            const name = task !== defaultTask ? chalk.blue(task.options.name) : `${chalk.green(task.options.name)} (default)`;
            const descriptionParts = [];
            if (task.options.description) {
                descriptionParts.push(task.options.description);
            }
            if (task.options.dependencies && task.options.dependencies.length > 0) {
                const deps = task.options.dependencies
                    .filter((task) => !task.options.hiddenFromTaskList)
                    .map((task) => task.options.name)
                    .sort(stringSorter)
                    .map((v) => chalk.blue(v));
                descriptionParts.push(`Depends on: ${deps.join(", ")}`);
            }
            return { name, description: descriptionParts.join("\n") };
        }),
    });
    return commandLineUsage(sections);
}
//# sourceMappingURL=formatTasks.js.map